@@ -7,11 +7,11 @@ package HPCD::SGE;
 
 =head1 VERSION
 
-Version 0.45
+Version 0.46
 
 =cut
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 =head1 SYNOPSIS
 
@@ -78,7 +78,13 @@ If a stage is terminated because it exceeds the requested memory resource
 limit, then it will normally be retried using a higher limit.
 The default is to first try with '2G' (if no h_mem or mem resource limit
 is explicitly specified).  After mem failures, the next larger size in the
-default sequence (2G 4G 8G 16G 32G) is attempted.
+default sequence (2G 4G 8G 16G 32G) is attempted.  The detection for
+exceeding the memory requirement is concoluted, because SGE does not return
+a clear indiciation that it terminated the job.  HPCI considers it to have
+been a memory overrun if the memory usage exceeds a threshold (default is 99%
+of requested memory allocation, but the attribute B<retry_mem_percent>
+can be specified to provide an alternate range), or if one of a few common
+memory allocation failure requests is seen.
 
 =back
 
